% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_EFA_factorability_table.R
\name{make_EFA_factorability_table}
\alias{make_EFA_factorability_table}
\title{Check EFA Factorability and Return Summary Table}
\usage{
make_EFA_factorability_table(data, items, scale_name = "Overall")
}
\arguments{
\item{data}{A data frame containing the variables.}

\item{items}{A character vector of column names to be included in the analysis.}

\item{scale_name}{Character. A label for the scale (e.g., "GLPFS"). Defaults to "Overall".}
}
\value{
A data frame with one row containing the scale-level factorability diagnostics.
}
\description{
This function calculates the overall Kaiser-Meyer-Olkin (KMO) MSA,
Bartlett's Test of Sphericity, and the Determinant of the correlation matrix.
}
