% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_alpha_table.R
\name{make_alpha_table}
\alias{make_alpha_table}
\title{Wrap a pre computed psych::alpha object into a single row table with N and alpha only.}
\usage{
make_alpha_table(alpha_res, scale_name = "Scale")
}
\arguments{
\item{alpha_res}{A psych::alpha object (already computed)}

\item{scale_name}{Name of the scale (default: "Scale")}
}
\value{
A data frame with three columns: Scale,N, and Alpha.
}
\description{
Extracts only the Scale Name, Sample Size (N), and Cronbach's Alpha
from a `psych::alpha` object.
}
\examples{
\dontrun{
library(psych)
res <- psych::alpha(mtcars[,1:3])
make_alpha_table(res, scale_name = "Car Scale")
}
}
